@@ -42,7 +42,7 @@ VALUE cgsl_vector_complex_col, cgsl_vector_complex_col_view;
 VALUE cgsl_vector_int, cgsl_vector_int_col;
 VALUE cgsl_vector_int_view, cgsl_vector_int_col_view;
 VALUE cgsl_vector_int_view_ro, cgsl_vector_int_col_view_ro;
-VALUE cgsl_matrix_int, cgsl_matrix_int_view;
+VALUE cgsl_matrix_int, cgsl_matrix_int_view, cgsl_matrix_int_view_ro;
 
 double* get_vector_ptr(VALUE ary, size_t *stride, size_t *n)
 {
@@ -632,7 +632,8 @@ void Init_gsl_array(VALUE module)
   /*****/
   cgsl_matrix_int = rb_define_class_under(cgsl_matrix, "Int", cGSL_Object);
   cgsl_matrix_int_view = rb_define_class_under(cgsl_matrix_int, "View", cgsl_matrix_int);
-
+  cgsl_matrix_int_view_ro = rb_define_class_under(cgsl_matrix_int_view, "ReadOnly",
+					      cgsl_matrix_int_view);
   /*****/
   Init_gsl_block_init(module);
   Init_gsl_block_int_init(module);
@@ -652,6 +653,8 @@ void Init_gsl_array(VALUE module)
 
   rb_define_method(cgsl_vector_view_ro, "set", rb_gsl_obj_read_only, -1);
   rb_define_method(cgsl_matrix_view_ro, "set", rb_gsl_obj_read_only, -1);
+  rb_define_method(cgsl_vector_int_view_ro, "set", rb_gsl_obj_read_only, -1);
+  rb_define_method(cgsl_matrix_int_view_ro, "set", rb_gsl_obj_read_only, -1);  
   rb_define_method(cgsl_vector_complex_view_ro, "set", rb_gsl_obj_read_only, -1);
   rb_define_method(cgsl_matrix_complex_view_ro, "set", rb_gsl_obj_read_only, -1);
 
