@@ -808,10 +808,11 @@ static VALUE rb_gsl_complex_arccoth(int argc, VALUE *argv, VALUE obj)
   return rb_gsl_complex_operate2(gsl_complex_arccoth, argc, argv, obj);
 }
 
-int rbgsl_complex_equal(const gsl_complex *z1, const gsl_complex *z2)
+int rbgsl_complex_equal(const gsl_complex *z1, const gsl_complex *z2,
+      double eps)
 {
-  if (z1->dat[0] != z2->dat[0]) return 0;
-  if (z1->dat[1] != z2->dat[1]) return 0;
+  if (gsl_fcmp(z1->dat[0], z2->dat[0], eps) != 0) return 0;
+  if (gsl_fcmp(z1->dat[1], z2->dat[1], eps) != 0) return 0;  
   return 1;
 }
 
@@ -822,13 +823,26 @@ int rbgsl_complex_zero(const gsl_complex *z1)
   return 1;
 }
 
-static VALUE rb_gsl_complex_equal(VALUE obj, VALUE zz)
+static VALUE rb_gsl_complex_equal(int argc, VALUE *argv, VALUE obj)
 {
   gsl_complex *z1 = NULL, *z2 = NULL;
-  CHECK_COMPLEX(zz);
+  double eps = 1e-8;
+  
+  switch (argc) {
+  case 1:
+    CHECK_COMPLEX(argv[0]);
+    Data_Get_Struct(argv[0], gsl_complex, z2);      
+    break;
+  case 2:
+    CHECK_COMPLEX(argv[0]);
+    Data_Get_Struct(argv[0], gsl_complex, z2);
+    eps = NUM2DBL(argv[1]);
+    break;
+  default:
+    rb_raise(rb_eArgError, "Wrong number of argumsnts (%d for 1 or 2)", argc);
+  }
   Data_Get_Struct(obj, gsl_complex, z1);
-  Data_Get_Struct(zz, gsl_complex, z2);
-  if (rbgsl_complex_equal(z1, z2)) return Qtrue;
+  if (rbgsl_complex_equal(z1, z2, eps)) return Qtrue;
   else return Qfalse;
 }
 
@@ -866,7 +880,7 @@ void Init_gsl_complex(VALUE module)
   rb_define_singleton_method(cgsl_complex, "[]", rb_gsl_complex_new, -1);
   rb_define_singleton_method(cgsl_complex, "polar", rb_gsl_complex_polar, 2);
 
-  rb_define_method(cgsl_complex, "equal?", rb_gsl_complex_equal, 1);
+  rb_define_method(cgsl_complex, "equal?", rb_gsl_complex_equal, -1);
   rb_define_alias(cgsl_complex, "==", "equal?");
   rb_define_method(cgsl_complex, "zero?", rb_gsl_complex_zero, 0);
 
