@@ -1195,6 +1195,32 @@ static VALUE rb_gsl_fft_halfcomplex_to_nrc(int argc, VALUE *argv, VALUE obj)
   return Data_Wrap_Struct(cgsl_vector, 0, gsl_vector_free, vnew);
 }
 
+static VALUE rb_gsl_fft_halfcomplex_amp_phase(VALUE module, VALUE obj)
+{
+  gsl_vector *v;
+  gsl_vector *amp, *phase;
+  double re, im;
+  VALUE vamp, vphase;
+  size_t i;
+  CHECK_VECTOR(obj);
+  Data_Get_Struct(obj, gsl_vector, v);
+  amp = gsl_vector_alloc(v->size/2);
+  phase = gsl_vector_alloc(v->size/2);
+  gsl_vector_set(amp, 0, gsl_vector_get(v, 0));
+  gsl_vector_set(phase, 0, 0);  
+  gsl_vector_set(amp, amp->size-1, gsl_vector_get(v, v->size-1));
+  gsl_vector_set(phase, phase->size-1, 0);    
+  for (i = 1; i < v->size-1; i+=2) {
+    re = gsl_vector_get(v, i);
+    im = gsl_vector_get(v, i+1);    
+    gsl_vector_set(amp, i/2+1, sqrt(re*re + im*im));
+    gsl_vector_set(phase, i/2+1, atan2(im, re));
+  }
+  vamp = Data_Wrap_Struct(VECTOR_ROW_COL(obj), 0, gsl_vector_free, amp);
+  vphase = Data_Wrap_Struct(VECTOR_ROW_COL(obj), 0, gsl_vector_free, phase);
+  return rb_ary_new3(2, vamp, vphase);
+}
+
 void Init_gsl_fft(VALUE module)
 {
   VALUE mgsl_fft_complex_radix2, mgsl_fft_real_radix2;
@@ -1550,5 +1576,8 @@ void Init_gsl_fft(VALUE module)
 			     rb_gsl_fft_halfcomplex_to_nrc, -1);
   rb_define_method(cgsl_vector, "to_nrc_order",
 			     rb_gsl_fft_halfcomplex_to_nrc, -1);
+			     
+  rb_define_singleton_method(mgsl_fft_halfcomplex, "amp_phase",
+			     rb_gsl_fft_halfcomplex_amp_phase, 1);
 
 }
