@@ -279,7 +279,7 @@ static VALUE rb_gsl_function_graph(int argc, VALUE *argv, VALUE obj)
     fprintf(fp, "%e %e\n", x, y);
   }
   fflush(fp);
-  fclose(fp);
+ pclose(fp);
   fp = NULL;
   if (flag == 1) gsl_vector_free(v);
   return Qtrue;
