@@ -614,8 +614,10 @@ void Init_gsl_narray(VALUE module)
   rb_define_singleton_method(cgsl_matrix, "na_to_gslm_view", rb_gsl_na_to_gsl_matrix_view, 1);
   rb_define_singleton_method(cgsl_matrix, "na_to_gm_view", rb_gsl_na_to_gsl_matrix_view, 1);
 
-  rb_define_method(cNArray, "to_gm", rb_gsl_na_to_gsl_matrix_method, 0);
-  rb_define_method(cNArray, "to_gm_view", rb_gsl_na_to_gsl_matrix_view_method, 0);
+  rb_define_method(cNArray, "to_gslm", rb_gsl_na_to_gsl_matrix_method, 0);
+  rb_define_alias(cNArray, "to_gm", "to_gslm");
+  rb_define_method(cNArray, "to_gslm_view", rb_gsl_na_to_gsl_matrix_view_method, 0);
+  rb_define_alias(cNArray, "to_gm_view", "to_gslm_view");  
 
   /*****/
   rb_define_method(cgsl_matrix_int, "to_na", rb_gsl_matrix_int_to_na, 0);
