@@ -119,7 +119,7 @@ static VALUE rb_gsl_histogram_alloc_from_file(VALUE klass, VALUE name)
   fp = popen(buf, "r");
   if (fp == NULL) rb_raise(rb_eIOError, "popen failed.");
   fgets(buf, 1024, fp);
-  fclose(fp);
+  pclose(fp);
   sscanf(buf, "%d", &nn);
   n = (size_t) nn;      /* vector length */
   fp = fopen(filename, "r");
@@ -882,9 +882,16 @@ static VALUE rb_gsl_histogram_print(VALUE obj)
 static VALUE rb_gsl_histogram_pdf_alloc(VALUE klass, VALUE nn)
 {
   gsl_histogram_pdf *h = NULL;
+  gsl_histogram *h0 = NULL;
 #ifdef GSL_0_9_4_LATER
-  CHECK_FIXNUM(nn);
-  h = gsl_histogram_pdf_alloc(FIX2INT(nn));
+	if (rb_obj_is_kind_of(nn, cgsl_histogram)) {
+		Data_Get_Struct(nn, gsl_histogram, h0);
+	  h = gsl_histogram_pdf_alloc(h0->n);
+	  gsl_histogram_pdf_init(h, h0);
+	} else {
+	  CHECK_FIXNUM(nn);
+    h = gsl_histogram_pdf_alloc(FIX2INT(nn));
+  }
 #else
   gsl_histogram *hh = NULL;
   Data_Get_Struct(nn, gsl_histogram, hh);
@@ -963,7 +970,7 @@ static VALUE rb_gsl_histogram_graph(int argc, VALUE *argv, VALUE obj)
     fprintf(fp, "%e %e\n%e %e\n", v->range[i], v->bin[i], v->range[i+1], v->bin[i]);
   }
   fflush(fp);
-  fclose(fp);
+ pclose(fp);
   fp = NULL;
   return Qtrue;
 #else
@@ -1002,7 +1009,7 @@ static VALUE rb_gsl_histogram_plot(int argc, VALUE *argv, VALUE obj)
   }
   fprintf(fp, "e\n");
   fflush(fp);
-  fclose(fp);
+  pclose(fp);
   fp = NULL;
   return Qtrue;
 #else
