@@ -1112,17 +1112,17 @@ void Init_gsl_integration(VALUE module)
 		   rb_gsl_integration_workspace_elist, 0);
 
   /*****/
-  rb_define_singleton_method(mgsl_integ, "qng", rb_gsl_integration_qng, -1);
-  rb_define_singleton_method(mgsl_integ, "qag", rb_gsl_integration_qag, -1);
-  rb_define_singleton_method(mgsl_integ, "qags", rb_gsl_integration_qags, -1);
-  rb_define_singleton_method(mgsl_integ, "qagp", rb_gsl_integration_qagp, -1);
-  rb_define_singleton_method(mgsl_integ, "qagi", rb_gsl_integration_qagi, -1);
-  rb_define_singleton_method(mgsl_integ, "qagiu", rb_gsl_integration_qagiu, -1);
-  rb_define_singleton_method(mgsl_integ, "qagil", rb_gsl_integration_qagil, -1);
-  rb_define_singleton_method(mgsl_integ, "qawc", rb_gsl_integration_qawc, -1);
-  rb_define_singleton_method(mgsl_integ, "qaws", rb_gsl_integration_qaws, -1);
-  rb_define_singleton_method(mgsl_integ, "qawo", rb_gsl_integration_qawo, -1);
-  rb_define_singleton_method(mgsl_integ, "qawf", rb_gsl_integration_qawf, -1);
+  rb_define_module_function(mgsl_integ, "qng", rb_gsl_integration_qng, -1);
+  rb_define_module_function(mgsl_integ, "qag", rb_gsl_integration_qag, -1);
+  rb_define_module_function(mgsl_integ, "qags", rb_gsl_integration_qags, -1);
+  rb_define_module_function(mgsl_integ, "qagp", rb_gsl_integration_qagp, -1);
+  rb_define_module_function(mgsl_integ, "qagi", rb_gsl_integration_qagi, -1);
+  rb_define_module_function(mgsl_integ, "qagiu", rb_gsl_integration_qagiu, -1);
+  rb_define_module_function(mgsl_integ, "qagil", rb_gsl_integration_qagil, -1);
+  rb_define_module_function(mgsl_integ, "qawc", rb_gsl_integration_qawc, -1);
+  rb_define_module_function(mgsl_integ, "qaws", rb_gsl_integration_qaws, -1);
+  rb_define_module_function(mgsl_integ, "qawo", rb_gsl_integration_qawo, -1);
+  rb_define_module_function(mgsl_integ, "qawf", rb_gsl_integration_qawf, -1);
 }
 
 #undef EPSABS_DEFAULT
