@@ -19,6 +19,9 @@ EXTERN VALUE mgsl_linalg;
 EXTERN VALUE cgsl_complex;
 
 static VALUE cgsl_matrix_complex_LU;
+#ifdef GSL_1_10_LATER
+static VALUE cgsl_matrix_complex_C;
+#endif
 
 VALUE rb_gsl_linalg_complex_LU_decomp(int argc, VALUE *argv, VALUE obj)
 {
@@ -448,6 +451,170 @@ static VALUE rb_gsl_linalg_complex_LU_sgndet(int argc, VALUE *argv, VALUE obj)
 }
 #endif
 
+#ifdef GSL_1_10_LATER
+
+static VALUE rb_gsl_linalg_cholesky_decomp(int argc, VALUE *argv, VALUE obj)
+{
+  gsl_matrix_complex *A = NULL, *Atmp = NULL;
+  switch(TYPE(obj)) {
+  case T_MODULE:  case T_CLASS:  case T_OBJECT:
+    if (argc != 1) rb_raise(rb_eArgError, "wrong number of argument (%d for 1)",
+			    argc);
+    CHECK_MATRIX_COMPLEX(argv[0]);
+    Data_Get_Struct(argv[0], gsl_matrix_complex, Atmp);
+    break;
+  default:
+    CHECK_MATRIX_COMPLEX(obj);
+    Data_Get_Struct(obj, gsl_matrix_complex, Atmp);
+    break;
+  }
+  A = make_matrix_complex_clone(Atmp);
+  gsl_linalg_complex_cholesky_decomp(A);
+  return Data_Wrap_Struct(cgsl_matrix_complex_C, 0, gsl_matrix_complex_free, A);
+}
+
+static VALUE rb_gsl_linalg_cholesky_solve(int argc, VALUE *argv, VALUE obj)
+{
+  gsl_matrix_complex *A = NULL, *Atmp = NULL;
+  gsl_vector_complex *b = NULL, *x = NULL;
+  int flagb = 0, flaga = 0;
+  VALUE vA, vb;
+  switch(TYPE(obj)) {
+  case T_MODULE:  case T_CLASS:  case T_OBJECT:
+    if (argc != 2) rb_raise(rb_eArgError, "wrong number of argument (%d for 2)",
+			    argc);
+    vA = argv[0];
+    vb = argv[1];
+    break;
+  default:
+    if (argc != 1) rb_raise(rb_eArgError, "wrong number of argument (%d for 1)",
+			    argc);
+    vA = obj;
+    vb = argv[0];
+    break;
+  }
+  CHECK_MATRIX_COMPLEX(vA);
+  Data_Get_Struct(vA, gsl_matrix_complex, Atmp);
+  CHECK_VECTOR_COMPLEX(vb);
+  Data_Get_Struct(vb, gsl_vector_complex, b);
+
+  if (CLASS_OF(vA) == cgsl_matrix_complex_C) {
+    A = Atmp;
+  } else {
+    A = make_matrix_complex_clone(Atmp);
+    flaga = 1;
+    gsl_linalg_complex_cholesky_decomp(A);
+  }
+  x = gsl_vector_complex_alloc(b->size);
+  gsl_linalg_complex_cholesky_solve(A, b, x);
+  if (flaga == 1) gsl_matrix_complex_free(A);
+  if (flagb == 1) gsl_vector_complex_free(b);
+  return Data_Wrap_Struct(cgsl_vector_complex_col, 0, gsl_vector_complex_free, x);
+}
+
+
+static VALUE rb_gsl_linalg_cholesky_svx(int argc, VALUE *argv, VALUE obj)
+{
+  gsl_matrix_complex *A = NULL, *Atmp = NULL;
+  gsl_vector_complex *b = NULL;
+  int flaga = 0;
+  VALUE vA, vb;
+  switch(TYPE(obj)) {
+  case T_MODULE:  case T_CLASS:  case T_OBJECT:
+    if (argc != 2) rb_raise(rb_eArgError, "wrong number of argument (%d for 2)",
+			    argc);
+    vA = argv[0];
+    vb = argv[1];
+    break;
+  default:
+    if (argc != 1) rb_raise(rb_eArgError, "wrong number of argument (%d for 1)",
+			    argc);
+    vA = obj;
+    vb = argv[0];
+    break;
+  }
+  CHECK_MATRIX_COMPLEX(vA);
+  Data_Get_Struct(vA, gsl_matrix_complex, Atmp);
+  CHECK_VECTOR_COMPLEX(vb);
+  Data_Get_Struct(vb, gsl_vector_complex, b);
+  if (CLASS_OF(vA) == cgsl_matrix_complex_C) {
+    A = Atmp;
+  } else {
+    A = make_matrix_complex_clone(Atmp);
+    flaga = 1;
+    gsl_linalg_complex_cholesky_decomp(A);
+  }
+  gsl_linalg_complex_cholesky_svx(A, b);
+  if (flaga == 1) gsl_matrix_complex_free(A);
+  return vb;
+}
+
+
+static VALUE rb_gsl_linalg_complex_householder_transform(int argc, VALUE *argv, VALUE obj)
+{
+  gsl_vector_complex *v = NULL;
+  gsl_complex *z;
+  switch (TYPE(obj)) {
+  case T_MODULE:  case T_CLASS:  case T_OBJECT:
+    if (argc < 1) rb_raise(rb_eArgError, "too few arguments.");
+    CHECK_VECTOR_COMPLEX(argv[0]);
+    Data_Get_Struct(argv[0], gsl_vector_complex, v);
+    break;
+  default:
+    Data_Get_Struct(obj, gsl_vector_complex, v);
+    break;
+  }
+  z = (gsl_complex*) malloc(sizeof(gsl_complex));
+  *z = gsl_linalg_complex_householder_transform(v);
+  return Data_Wrap_Struct(cgsl_complex, 0, free, z);
+}
+
+/* singleton */
+static VALUE rb_gsl_linalg_complex_householder_hm(VALUE obj, VALUE t, VALUE vv, VALUE aa)
+{
+  gsl_vector_complex *v = NULL;
+  gsl_complex *tau;
+  gsl_matrix_complex *A = NULL;
+  CHECK_COMPLEX(t);  
+  CHECK_VECTOR_COMPLEX(vv);
+  CHECK_MATRIX_COMPLEX(aa);
+  Data_Get_Struct(t, gsl_complex, tau);
+  Data_Get_Struct(vv, gsl_vector_complex, v);
+  Data_Get_Struct(aa, gsl_matrix_complex, A);
+  gsl_linalg_complex_householder_hm(*tau, v, A);
+  return aa;
+}
+
+static VALUE rb_gsl_linalg_complex_householder_mh(VALUE obj, VALUE t, VALUE vv, VALUE aa)
+{
+  gsl_vector_complex *v = NULL;
+  gsl_complex *tau;
+  gsl_matrix_complex *A = NULL;
+  CHECK_COMPLEX(t);  
+  CHECK_VECTOR_COMPLEX(vv);
+  CHECK_MATRIX_COMPLEX(aa);
+  Data_Get_Struct(t, gsl_complex, tau);
+  Data_Get_Struct(vv, gsl_vector_complex, v);
+  Data_Get_Struct(aa, gsl_matrix_complex, A);
+  gsl_linalg_complex_householder_hm(*tau, v, A);
+  return aa;
+}
+
+static VALUE rb_gsl_linalg_complex_householder_hv(VALUE obj, VALUE t, VALUE vv, VALUE ww)
+{
+  gsl_vector_complex *v = NULL, *w = NULL;
+  gsl_complex *tau;
+  CHECK_COMPLEX(t);    
+  CHECK_VECTOR_COMPLEX(vv);
+  CHECK_VECTOR_COMPLEX(ww);
+  Data_Get_Struct(t, gsl_complex, tau);
+  Data_Get_Struct(vv, gsl_vector_complex, v);
+  Data_Get_Struct(ww, gsl_vector_complex, w);
+  gsl_linalg_complex_householder_hv(*tau, v, w);
+  return ww;
+}
+#endif
+
 void Init_gsl_linalg_complex(VALUE module)
 {
   VALUE mgsl_linalg_complex;
@@ -534,4 +701,43 @@ void Init_gsl_linalg_complex(VALUE module)
   rb_define_alias(cgsl_matrix_complex, "sgndet", "LU_sgndet");
   rb_define_method(cgsl_matrix_complex_LU, "LU_sgndet", rb_gsl_linalg_complex_LU_sgndet, -1);
 #endif
+
+#ifdef GSL_1_10_LATER
+  VALUE mgsl_linalg_complex_chol;
+  mgsl_linalg_complex_chol = rb_define_module_under(mgsl_linalg_complex, "Cholesky");
+  cgsl_matrix_complex_C = rb_define_class_under(mgsl_linalg_complex_chol, "CholeskyMatrix", cgsl_matrix_complex);    
+  rb_define_singleton_method(mgsl_linalg_complex_chol, "decomp", rb_gsl_linalg_cholesky_decomp, -1);
+  rb_define_method(cgsl_matrix_complex, "cholesky_decomp", rb_gsl_linalg_cholesky_decomp, -1);  
+  rb_define_singleton_method(mgsl_linalg_complex_chol, "solve", rb_gsl_linalg_cholesky_solve, -1);
+  rb_define_method(cgsl_matrix_complex, "cholesky_solve", rb_gsl_linalg_cholesky_solve, -1);   
+  
+  rb_define_method(cgsl_matrix_complex, "cholesky_solve", rb_gsl_linalg_cholesky_solve, -1);
+  rb_define_method(cgsl_matrix_complex_C, "solve", rb_gsl_linalg_cholesky_solve, -1);
+  rb_define_singleton_method(mgsl_linalg_complex_chol, "svx", rb_gsl_linalg_cholesky_svx, -1);
+  rb_define_method(cgsl_matrix_complex, "cholesky_svx", rb_gsl_linalg_cholesky_svx, -1);
+  rb_define_method(cgsl_matrix_complex_C, "svx", rb_gsl_linalg_cholesky_svx, -1);
+
+  VALUE mgsl_linalg_complex_Householder = rb_define_module_under(mgsl_linalg_complex, "Householder");
+ rb_define_singleton_method(mgsl_linalg_complex, "householder_transform", 
+			     rb_gsl_linalg_complex_householder_transform, -1);
+  rb_define_singleton_method(mgsl_linalg_complex_Householder, "transform", 
+			     rb_gsl_linalg_complex_householder_transform, -1);
+  rb_define_method(cgsl_vector, "householder_transform", 
+		   rb_gsl_linalg_complex_householder_transform, -1);
+
+  rb_define_singleton_method(mgsl_linalg_complex, "householder_hm", 
+			     rb_gsl_linalg_complex_householder_hm, 3);
+  rb_define_singleton_method(mgsl_linalg_complex_Householder, "hm", 
+			     rb_gsl_linalg_complex_householder_hm, 3);
+
+  rb_define_singleton_method(mgsl_linalg_complex, "householder_mh", 
+			     rb_gsl_linalg_complex_householder_mh, 3);
+  rb_define_singleton_method(mgsl_linalg_complex_Householder, "mh", 
+			     rb_gsl_linalg_complex_householder_mh, 3);
+
+  rb_define_singleton_method(mgsl_linalg_complex, "householder_hv", 
+			     rb_gsl_linalg_complex_householder_hv, 3);
+  rb_define_singleton_method(mgsl_linalg_complex_Householder, "hv", 
+			     rb_gsl_linalg_complex_householder_hv, 3);
+#endif			     
 }
