@@ -285,7 +285,15 @@ static VALUE rb_gsl_hypot(VALUE obj, VALUE x, VALUE y)
 {
   return rb_gsl_math_eval2(gsl_hypot, x, y);
 }
-
+#ifdef GSL_1_10_LATER
+static VALUE rb_gsl_hypot3(VALUE obj, VALUE x, VALUE y, VALUE z)
+{
+  Need_Float(x);
+  Need_Float(y);
+  Need_Float(z);    
+  return rb_float_new(gsl_hypot3(NUM2DBL(x), NUM2DBL(y), NUM2DBL(z)));
+}
+#endif
 static VALUE rb_gsl_acosh(VALUE obj, VALUE x)
 {
   if (COMPLEX_P(x) || VECTOR_COMPLEX_P(x) || MATRIX_COMPLEX_P(x)) 
@@ -311,7 +319,7 @@ static VALUE rb_gsl_atanh(VALUE obj, VALUE x)
 /* xx: Numeric, Complex, Vector, Matrix
    nn: Numeric, Complex
 */
-static VALUE rb_gsl_pow(VALUE obj, VALUE xx, VALUE nn)
+VALUE rb_gsl_pow(VALUE obj, VALUE xx, VALUE nn)
 {
   VALUE x, ary, argv[2];
   size_t i, j, size;
@@ -662,6 +670,9 @@ void Init_gsl_math(VALUE module)
   rb_define_module_function(module, "log1p", rb_gsl_log1p, 1);
   rb_define_module_function(module, "expm1", rb_gsl_expm1, 1);
   rb_define_module_function(module, "hypot", rb_gsl_hypot, 2);
+#ifdef GSL_1_10_LATER
+  rb_define_module_function(module, "hypot3", rb_gsl_hypot3, 3);  
+#endif
   rb_define_module_function(module, "acosh", rb_gsl_acosh, 1);
   rb_define_module_function(module, "asinh", rb_gsl_asinh, 1);
   rb_define_module_function(module, "atanh", rb_gsl_atanh, 1);
