@@ -1312,6 +1312,55 @@ static VALUE rb_gsl_matrix_complex_indgen_singleton(int argc, VALUE *argv, VALUE
   return Data_Wrap_Struct(cgsl_matrix_complex, 0, gsl_matrix_complex_free, vnew);
 }
 
+
+static int gsl_matrix_complex_equal(const gsl_matrix_complex *m1,
+  const gsl_matrix_complex *m2, double eps)
+{
+  gsl_complex z1, z2;
+  size_t i, j;
+  if (m1->size1 != m2->size1) return 0;
+  if (m1->size2 != m2->size2) return 0;  
+  for (i = 0; i < m1->size1; i++) {
+    for (j = 0; j < m1->size2; j++) {    
+      z1 = gsl_matrix_complex_get(m1, i, j);
+      z2 = gsl_matrix_complex_get(m2, i, j);
+      if (!rbgsl_complex_equal(&z1, &z2, eps)) return 0;
+    }
+  }
+  return 1;
+}
+
+static VALUE rb_gsl_matrix_complex_equal(int argc, VALUE *argv, VALUE obj)
+{
+  gsl_matrix_complex *m1, *m2;
+  double eps = 1e-8;
+  int ret;
+  switch (argc) {
+  case 1:
+    eps = 1e-8;
+    break;
+  case 2:
+    eps = NUM2DBL(argv[1]);
+    break;
+  default:
+    rb_raise(rb_eArgError, "Wrong number of arguments (%d for 1 or 2)\n", argc);
+  }
+  Data_Get_Struct(obj, gsl_matrix_complex, m1);
+  CHECK_MATRIX_COMPLEX(argv[0]);
+  Data_Get_Struct(argv[0], gsl_matrix_complex, m2);
+  ret = gsl_matrix_complex_equal(m1, m2, eps);
+  if (ret == 1) return Qtrue;
+  else return Qfalse;
+}
+
+static VALUE rb_gsl_matrix_complex_not_equal(int argc, VALUE *argv, VALUE obj)
+{
+  VALUE ret;
+  ret = rb_gsl_matrix_complex_equal(argc, argv, obj);
+  if (ret == Qtrue) return Qfalse;
+  else return Qtrue;
+}
+
 void Init_gsl_matrix_complex(VALUE module)
 {
   //  rb_define_singleton_method(cgsl_matrix_complex, "new", rb_gsl_matrix_complex_new, 2);
@@ -1453,4 +1502,9 @@ void Init_gsl_matrix_complex(VALUE module)
   rb_define_method(cgsl_matrix_complex, "indgen", rb_gsl_matrix_complex_indgen, -1);
   rb_define_method(cgsl_matrix_complex, "indgen!", rb_gsl_matrix_complex_indgen_bang, -1);
   rb_define_singleton_method(cgsl_matrix_complex, "indgen", rb_gsl_matrix_complex_indgen_singleton, -1);
+  
+  rb_define_method(cgsl_matrix_complex, "equal?", rb_gsl_matrix_complex_equal, -1);
+  rb_define_alias(cgsl_matrix_complex, "==", "equal?");
+  rb_define_method(cgsl_matrix_complex, "not_equal?", rb_gsl_matrix_complex_not_equal, -1);
+  rb_define_alias(cgsl_matrix_complex, "!=", "not_equal?");    
 }
