@@ -235,7 +235,8 @@ GSL_TYPE(gsl_matrix)* FUNCTION(gsl_matrix,alloc_from_colvectors)(int argc, VALUE
   if (argc < 1) rb_raise(rb_eArgError, "too few arguments");
   CHECK_VEC(argv[0]);
   Data_Get_Struct(argv[0], GSL_TYPE(gsl_vector), v);
-  m = FUNCTION(gsl_matrix,alloc)(argc, v->size);
+//  m = FUNCTION(gsl_matrix,alloc)(argc, v->size);
+  m = FUNCTION(gsl_matrix,alloc)(v->size, argc);  
   if (m == NULL) rb_raise(rb_eNoMemError, "gsl_matrix_alloc failed");
   for (i = 0; i < argc; i++) {
     CHECK_VEC(argv[i]);
@@ -1135,6 +1136,29 @@ static VALUE FUNCTION(rb_gsl_matrix,column)(VALUE obj, VALUE j)
   return Data_Wrap_Struct(QUALIFIED_VIEW(cgsl_vector,col_view), 0, free, vv);
 }
 
+#ifdef GSL_1_10_LATER
+static VALUE FUNCTION(rb_gsl_matrix,subrow)(VALUE obj, VALUE i, VALUE offset,
+  VALUE n)
+{
+  GSL_TYPE(gsl_matrix) *m = NULL;
+  QUALIFIED_VIEW(gsl_vector,view) *vv = NULL;
+  Data_Get_Struct(obj, GSL_TYPE(gsl_matrix), m);
+  vv = ALLOC(QUALIFIED_VIEW(gsl_vector,view));
+  *vv = FUNCTION(gsl_matrix,subrow)(m, FIX2INT(i), FIX2INT(offset), FIX2INT(n));
+  return Data_Wrap_Struct(QUALIFIED_VIEW(cgsl_vector,view), 0, free, vv);
+}
+static VALUE FUNCTION(rb_gsl_matrix,subcolumn)(VALUE obj, VALUE j, VALUE offset,
+  VALUE n)
+{
+  GSL_TYPE(gsl_matrix) *m = NULL;
+  QUALIFIED_VIEW(gsl_vector,view) *vv = NULL;
+  Data_Get_Struct(obj, GSL_TYPE(gsl_matrix), m);
+  vv = ALLOC(QUALIFIED_VIEW(gsl_vector,view));
+  *vv = FUNCTION(gsl_matrix,subcolumn)(m, FIX2INT(j), FIX2INT(offset), FIX2INT(n));
+  return Data_Wrap_Struct(QUALIFIED_VIEW(cgsl_vector,col_view), 0, free, vv);
+}
+#endif
+
 static VALUE FUNCTION(rb_gsl_matrix,diagonal)(VALUE obj)
 {
   GSL_TYPE(gsl_matrix) *m = NULL;
@@ -1995,31 +2019,46 @@ static VALUE FUNCTION(rb_gsl_matrix,vertcat_singleton)(VALUE klass, VALUE mm, VA
 }
 
 #ifdef GSL_1_9_LATER
-static VALUE FUNCTION(rb_gsl_matrix,ispos)(VALUE obj)
-{
+static VALUE FUNCTION(rb_gsl_matrix,property)(VALUE obj,
+  int (*f)(const GSL_TYPE(gsl_matrix)*)) {
   GSL_TYPE(gsl_matrix) *m;
   Data_Get_Struct(obj, GSL_TYPE(gsl_matrix), m);
-  return INT2FIX(FUNCTION(gsl_matrix,ispos)(m));
+  return INT2FIX((*f)(m));  
+}
+
+static VALUE FUNCTION(rb_gsl_matrix,property2)(VALUE obj,
+  int (*f)(const GSL_TYPE(gsl_matrix) *)) {
+  GSL_TYPE(gsl_matrix) *m;  
+  Data_Get_Struct(obj, GSL_TYPE(gsl_matrix), m);
+  if ((*f)(m)) return Qtrue;
+  else return Qfalse;
+}
+static VALUE FUNCTION(rb_gsl_matrix,ispos)(VALUE obj)
+{
+  return FUNCTION(rb_gsl_matrix,property)(obj, FUNCTION(gsl_matrix,ispos));
 }
 static VALUE FUNCTION(rb_gsl_matrix,ispos2)(VALUE obj)
 {
-  GSL_TYPE(gsl_matrix) *m;
-  Data_Get_Struct(obj, GSL_TYPE(gsl_matrix), m);
-  if (FUNCTION(gsl_matrix,ispos)(m)) return Qtrue;
-  else return Qfalse;
+  return FUNCTION(rb_gsl_matrix,property2)(obj, FUNCTION(gsl_matrix,ispos));  
 }
 static VALUE FUNCTION(rb_gsl_matrix,isneg)(VALUE obj)
 {
-  GSL_TYPE(gsl_matrix) *m;
-  Data_Get_Struct(obj, GSL_TYPE(gsl_matrix), m);
-  return INT2FIX(FUNCTION(gsl_matrix,isneg)(m));
+  return FUNCTION(rb_gsl_matrix,property)(obj, FUNCTION(gsl_matrix,isneg));  
 }
 static VALUE FUNCTION(rb_gsl_matrix,isneg2)(VALUE obj)
 {
-  GSL_TYPE(gsl_matrix) *m;
-  Data_Get_Struct(obj, GSL_TYPE(gsl_matrix), m);
-  if (FUNCTION(gsl_matrix,isneg)(m)) return Qtrue;
-  else return Qfalse;
+  return FUNCTION(rb_gsl_matrix,property2)(obj, FUNCTION(gsl_matrix,isneg));  
+}
+#endif
+
+#ifdef GSL_1_10_LATER
+static VALUE FUNCTION(rb_gsl_matrix,isnonneg)(VALUE obj)
+{
+  return FUNCTION(rb_gsl_matrix,property)(obj, FUNCTION(gsl_matrix,isnonneg));  
+}
+static VALUE FUNCTION(rb_gsl_matrix,isnonneg2)(VALUE obj)
+{
+  return FUNCTION(rb_gsl_matrix,property2)(obj, FUNCTION(gsl_matrix,isnonneg));  
 }
 #endif
 
@@ -2177,6 +2216,14 @@ void FUNCTION(Init_gsl_matrix,init)(VALUE module)
 		   FUNCTION(rb_gsl_matrix,column), 1);
   rb_define_alias(GSL_TYPE(cgsl_matrix), "col", "column");
 
+#ifdef GSL_1_10_LATER
+ rb_define_method(GSL_TYPE(cgsl_matrix), "subrow", 
+		   FUNCTION(rb_gsl_matrix,subrow), 3);
+ rb_define_method(GSL_TYPE(cgsl_matrix), "subcolumn", 
+		   FUNCTION(rb_gsl_matrix,subcolumn), 3);
+  rb_define_alias(GSL_TYPE(cgsl_matrix), "subcol", "subcolumn");		   
+#endif
+
   rb_define_method(GSL_TYPE(cgsl_matrix), "diagonal", 
 		   FUNCTION(rb_gsl_matrix,diagonal), 0);
 
@@ -2298,6 +2345,12 @@ void FUNCTION(Init_gsl_matrix,init)(VALUE module)
   rb_define_method(GSL_TYPE(cgsl_matrix), "isneg", FUNCTION(rb_gsl_matrix,isneg), 0);
   rb_define_method(GSL_TYPE(cgsl_matrix), "isneg?", FUNCTION(rb_gsl_matrix,isneg2), 0);    
 #endif
+
+#ifdef GSL_1_10_LATER
+  rb_define_method(GSL_TYPE(cgsl_matrix), "isnonneg", FUNCTION(rb_gsl_matrix,isnonneg), 0);
+  rb_define_method(GSL_TYPE(cgsl_matrix), "isnonneg?", FUNCTION(rb_gsl_matrix,isnonneg2), 0);
+#endif
+
 }
 
 #undef NUMCONV
