@@ -28,7 +28,7 @@
       rb_class2name(CLASS_OF(x)));
 #endif
 
-static VALUE cgsl_multimin_function_fdf;
+VALUE cgsl_multimin_function_fdf;  /* Used also in multimin_fsdf.c */
 static VALUE cgsl_multimin_function;
 
 enum {
@@ -37,6 +37,9 @@ enum {
   GSL_FDFMINIMIZER_VECTOR_BFGS,
   GSL_FDFMINIMIZER_STEEPEST_DESCENT,
   GSL_FMINIMIZER_NMSIMPLEX,
+#ifdef GSL_1_9_LATER
+	GSL_FDFMINIMIZER_VECTOR_BFGS2,
+#endif
 };
 
 static const gsl_multimin_fdfminimizer_type* get_fdfminimizer_type(VALUE t);
@@ -119,8 +122,8 @@ static double rb_gsl_multimin_function_f(const gsl_vector *x, void *p)
   vx = Data_Wrap_Struct(cgsl_vector, 0, NULL, (gsl_vector *) x);
   proc = rb_ary_entry((VALUE) p, 0);
   vp = rb_ary_entry((VALUE) p, 1);
-  if (NIL_P(vp)) result = rb_funcall(proc, ID_call, 1, vx);
-  else result = rb_funcall(proc, ID_call, 2, vx, vp);
+  if (NIL_P(vp)) result = rb_funcall(proc, RBGSL_ID_call, 1, vx);
+  else result = rb_funcall(proc, RBGSL_ID_call, 2, vx, vp);
   return NUM2DBL(result);
 }
 
@@ -132,8 +135,8 @@ static VALUE rb_gsl_multimin_function_eval(VALUE obj, VALUE vx)
   ary = (VALUE) F->params;
   proc = rb_ary_entry(ary, 0);
   vp = rb_ary_entry(ary, 1);
-  if (NIL_P(vp)) result = rb_funcall(proc, ID_call, 1, vx);
-  else result = rb_funcall(proc, ID_call, 2, vx, vp);
+  if (NIL_P(vp)) result = rb_funcall(proc, RBGSL_ID_call, 1, vx);
+  else result = rb_funcall(proc, RBGSL_ID_call, 2, vx, vp);
   return result;
 }
 
@@ -261,7 +264,9 @@ static void set_function_fdf(int argc, VALUE *argv, gsl_multimin_function_fdf *F
     if (TYPE(argv[2]) == T_FIXNUM) {
       F->n = FIX2INT(argv[2]);
       rb_ary_store(ary, 2, Qnil);
-    } else rb_ary_store(ary, 2, argv[2]);
+    } else {
+			rb_ary_store(ary, 2, argv[2]);
+		}
     break;
   case 4:
   case 5:
@@ -307,7 +312,9 @@ static VALUE rb_gsl_multimin_function_fdf_set_procs(int argc, VALUE *argv, VALUE
     if (TYPE(argv[2]) == T_FIXNUM) {
       F->n = FIX2INT(argv[2]);
       rb_ary_store(ary, 2, Qnil);
-    } else rb_ary_store(ary, 2, argv[2]);
+    } else {
+			rb_ary_store(ary, 2, argv[2]);
+		}
     break;
   case 4:
   case 5:
@@ -344,8 +351,9 @@ static VALUE rb_gsl_multimin_function_fdf_set_params(int argc, VALUE *argv, VALU
   } else {
     ary = (VALUE) F->params;
   }
-  if (argc == 1) rb_ary_store(ary, 3, argv[0]);
-  else {
+  if (argc == 1) {
+		rb_ary_store(ary, 3, argv[0]);
+  } else {
     ary2 = rb_ary_new2(argc);
     for (i = 0; i < argc; i++) rb_ary_store(ary2, i, argv[i]);
     rb_ary_store(ary, 3, ary2);
@@ -368,8 +376,8 @@ double rb_gsl_multimin_function_fdf_f(const gsl_vector *x, void *p)
   ary = (VALUE) p;
   proc = rb_ary_entry(ary, 0);
   vp = rb_ary_entry(ary, RARRAY(ary)->len-1);
-  if (NIL_P(vp)) result = rb_funcall(proc, ID_call, 1, vx);
-  else result = rb_funcall(proc, ID_call, 2, vx, vp);
+  if (NIL_P(vp)) result = rb_funcall(proc, RBGSL_ID_call, 1, vx);
+  else result = rb_funcall(proc, RBGSL_ID_call, 2, vx, vp);
   return NUM2DBL(result);
 }
 
@@ -383,9 +391,9 @@ void rb_gsl_multimin_function_fdf_df(const gsl_vector *x, void *p,
   proc = rb_ary_entry(ary, 1);
   vp = rb_ary_entry(ary, RARRAY(ary)->len-1);
   if (NIL_P(vp)) {
-    rb_funcall(proc, ID_call, 2, vx, vg);
+    rb_funcall(proc, RBGSL_ID_call, 2, vx, vg);
   } else {
-    rb_funcall(proc, ID_call, 3, vx, vp, vg);
+    rb_funcall(proc, RBGSL_ID_call, 3, vx, vp, vg);
   }
 }
 
@@ -402,11 +410,11 @@ void rb_gsl_multimin_function_fdf_fdf(const gsl_vector *x, void *p,
   proc_fdf = rb_ary_entry(ary, 2);
   vp = rb_ary_entry(ary, RARRAY(ary)->len-1);
   if (NIL_P(vp)) {
-    result = rb_funcall(proc_f, ID_call, 1, vx);
-    rb_funcall(proc_df, ID_call, 2, vx, vg);
+    result = rb_funcall(proc_f, RBGSL_ID_call, 1, vx);
+    rb_funcall(proc_df, RBGSL_ID_call, 2, vx, vg);
   } else {
-    result = rb_funcall(proc_f, ID_call, 2, vx, vp);
-    rb_funcall(proc_df, ID_call, 3, vx, vp, vg);
+    result = rb_funcall(proc_f, RBGSL_ID_call, 2, vx, vp);
+    rb_funcall(proc_df, RBGSL_ID_call, 3, vx, vp, vg);
   }
   *f = NUM2DBL(result);
 }
@@ -427,13 +435,17 @@ static void define_const(VALUE klass1, VALUE klass2)
   rb_define_const(klass1, 
 		  "CONJUGATE_PR", INT2FIX(GSL_FDFMINIMIZER_CONJUGATE_PR));
   rb_define_const(klass1, 
-		  "VECTOR_BFGS", INT2FIX(GSL_FDFMINIMIZER_VECTOR_BFGS));
+		  "VECTOR_BFGS", INT2FIX(GSL_FDFMINIMIZER_VECTOR_BFGS));  
   rb_define_const(klass1, 
 		  "STEEPEST_DESCENT", INT2FIX(GSL_FDFMINIMIZER_STEEPEST_DESCENT));
 #ifdef GSL_1_3_LATER
   rb_define_const(klass2, 
 		  "NMSIMPLEX", INT2FIX(GSL_FMINIMIZER_NMSIMPLEX));
 #endif
+#ifdef GSL_1_9_LATER
+  rb_define_const(klass1, 
+		  "VECTOR_BFGS2", INT2FIX(GSL_FDFMINIMIZER_VECTOR_BFGS2));
+#endif
 }
 
 static const gsl_multimin_fdfminimizer_type* get_fdfminimizer_type(VALUE t)
@@ -450,6 +462,10 @@ static const gsl_multimin_fdfminimizer_type* get_fdfminimizer_type(VALUE t)
       return gsl_multimin_fdfminimizer_vector_bfgs;
     else if (str_tail_grep(name, "steepest_descent") == 0) 
       return gsl_multimin_fdfminimizer_steepest_descent;
+#ifdef GSL_1_9_LATER
+    else if (str_tail_grep(name, "vector_bfgs2") == 0) 
+      return gsl_multimin_fdfminimizer_vector_bfgs2;
+#endif
     else
       rb_raise(rb_eTypeError, "%s: unknown minimizer type", name);
     break;
@@ -463,6 +479,10 @@ static const gsl_multimin_fdfminimizer_type* get_fdfminimizer_type(VALUE t)
       return gsl_multimin_fdfminimizer_vector_bfgs; break;
     case GSL_FDFMINIMIZER_STEEPEST_DESCENT:
       return gsl_multimin_fdfminimizer_steepest_descent; break;
+#ifdef GSL_1_9_LATER
+    case GSL_FDFMINIMIZER_VECTOR_BFGS2:
+      return gsl_multimin_fdfminimizer_vector_bfgs2; break;
+#endif      
     default:
       rb_raise(rb_eTypeError, "%d: unknown type", FIX2INT(t));
       break;
@@ -689,6 +709,9 @@ static VALUE rb_gsl_multimin_test_size(VALUE obj, VALUE ss, VALUE ea)
 
 #endif
 
+#ifdef HAVE_GSL_GSL_MULTIMIN_FSDF_H
+void Init_multimin_fsdf(VALUE module);
+#endif
 
 /*****/
 void Init_gsl_multimin(VALUE module)
@@ -755,6 +778,11 @@ void Init_gsl_multimin(VALUE module)
     rb_define_method(cgsl_multimin_fminimizer, "size", rb_gsl_fminimizer_size, 0);
   rb_define_method(cgsl_multimin_fminimizer, "test_size", rb_gsl_fminimizer_test_size, 1);
 #endif
+
+
+#ifdef HAVE_GSL_GSL_MULTIMIN_FSDF_H
+	Init_multimin_fsdf(mgsl_multimin);
+#endif
 }
 #ifdef CHECK_MULTIMIN_FUNCTION
 #undef CHECK_MULTIMIN_FUNCTION
