@@ -1,7 +1,7 @@
 /*
   multiroots.c
   Ruby/GSL: Ruby extension library for GSL (GNU Scientific Library)
-    (C) Copyright 2001-2004 by Yoshiki Tsunesada
+    (C) Copyright 2001-2006 by Yoshiki Tsunesada
 
   Ruby/GSL is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License.
@@ -110,8 +110,8 @@ static int rb_gsl_multiroot_function_f(const gsl_vector *x, void *p, gsl_vector
   vf = Data_Wrap_Struct(cgsl_vector, 0, NULL, f);
   proc = rb_ary_entry((VALUE) p, 0);
   vp = rb_ary_entry((VALUE) p, 1);
-  if (NIL_P(vp)) rb_funcall(proc, ID_call, 2, vx, vf);
-  else rb_funcall(proc, ID_call, 3, vx, vp, vf);
+  if (NIL_P(vp)) rb_funcall(proc, RBGSL_ID_call, 2, vx, vf);
+  else rb_funcall(proc, RBGSL_ID_call, 3, vx, vp, vf);
   return GSL_SUCCESS;
 }
 
@@ -126,8 +126,8 @@ static VALUE rb_gsl_multiroot_function_eval(VALUE obj, VALUE vx)
   vf = Data_Wrap_Struct(cgsl_vector, 0, gsl_vector_free, f);
   proc = rb_ary_entry(ary, 0);
   vp = rb_ary_entry(ary, 1);
-  if (NIL_P(vp)) rb_funcall(proc, ID_call, 2, vx, vf);
-  else rb_funcall(proc, ID_call, 3, vx, vp, vf);
+  if (NIL_P(vp)) rb_funcall(proc, RBGSL_ID_call, 2, vx, vf);
+  else rb_funcall(proc, RBGSL_ID_call, 3, vx, vp, vf);
   return vf;
 }
 
@@ -344,8 +344,8 @@ static int rb_gsl_multiroot_function_fdf_f(const gsl_vector *x, void *p,
   ary = (VALUE) p;
   proc = rb_ary_entry(ary, 0);
   vp = rb_ary_entry(ary, 3);
-  if (NIL_P(vp)) rb_funcall(proc, ID_call, 2, vx, vf);
-  else rb_funcall(proc, ID_call, 3, vx, vp, vf);
+  if (NIL_P(vp)) rb_funcall(proc, RBGSL_ID_call, 2, vx, vf);
+  else rb_funcall(proc, RBGSL_ID_call, 3, vx, vp, vf);
   return GSL_SUCCESS;
 }
 
@@ -359,8 +359,8 @@ static int rb_gsl_multiroot_function_fdf_df(const gsl_vector *x, void *p,
   ary = (VALUE) p;
   proc = rb_ary_entry(ary, 1);
   vp = rb_ary_entry(ary, 3);
-  if (NIL_P(vp)) rb_funcall(proc, ID_call, 2, vx, vJ);
-  else rb_funcall(proc, ID_call, 3, vx, vp, vJ);
+  if (NIL_P(vp)) rb_funcall(proc, RBGSL_ID_call, 2, vx, vJ);
+  else rb_funcall(proc, RBGSL_ID_call, 3, vx, vp, vJ);
   return GSL_SUCCESS;
 }
 
@@ -379,15 +379,15 @@ static int rb_gsl_multiroot_function_fdf_fdf(const gsl_vector *x, void *p,
   vp = rb_ary_entry(ary, 3);
   if (NIL_P(proc_fdf)) {
     if (NIL_P(vp)) {
-      rb_funcall(proc_f, ID_call, 2, vx, vf);
-      rb_funcall(proc_df, ID_call, 2, vx, vJ);
+      rb_funcall(proc_f, RBGSL_ID_call, 2, vx, vf);
+      rb_funcall(proc_df, RBGSL_ID_call, 2, vx, vJ);
     } else {
-      rb_funcall(proc_f, ID_call, 3, vx, vp, vf);
-      rb_funcall(proc_df, ID_call, 3, vx, vp, vJ);
+      rb_funcall(proc_f, RBGSL_ID_call, 3, vx, vp, vf);
+      rb_funcall(proc_df, RBGSL_ID_call, 3, vx, vp, vJ);
     }
   } else {
-    if (NIL_P(vp)) rb_funcall(proc_fdf, ID_call, 3, vx,  vf, vJ);
-    else rb_funcall(proc_fdf, ID_call, 4, vx, vp, vf, vJ);
+    if (NIL_P(vp)) rb_funcall(proc_fdf, RBGSL_ID_call, 3, vx,  vf, vJ);
+    else rb_funcall(proc_fdf, RBGSL_ID_call, 4, vx, vp, vf, vJ);
   }
   return GSL_SUCCESS;
 }
