@@ -100,9 +100,9 @@ static int calc_func(double t, const double y[], double dydt[], void *data)
   vy = Data_Wrap_Struct(cgsl_vector_view_ro, 0, NULL, &ytmp);
   vdydt = Data_Wrap_Struct(cgsl_vector_view, 0, NULL, &dydttmp);
 
-  if (NIL_P(params)) result = rb_funcall((VALUE) proc, ID_call, 3, rb_float_new(t), 
+  if (NIL_P(params)) result = rb_funcall((VALUE) proc, RBGSL_ID_call, 3, rb_float_new(t), 
 					 vy, vdydt);
-  else result = rb_funcall((VALUE) proc, ID_call, 4, rb_float_new(t), vy, vdydt, params);
+  else result = rb_funcall((VALUE) proc, RBGSL_ID_call, 4, rb_float_new(t), vy, vdydt, params);
  
   return GSL_SUCCESS;
 }
@@ -133,9 +133,9 @@ static int calc_jac(double t, const double y[], double *dfdy, double dfdt[], voi
   vy = Data_Wrap_Struct(cgsl_vector_view_ro, 0, NULL, &ytmp);
   vmjac = Data_Wrap_Struct(cgsl_matrix_view, 0, NULL, &mv);
   vdfdt = Data_Wrap_Struct(cgsl_vector_view, 0, NULL, &dfdttmp);
-  if (NIL_P(params)) result = rb_funcall((VALUE) proc, ID_call, 4, rb_float_new(t),
+  if (NIL_P(params)) result = rb_funcall((VALUE) proc, RBGSL_ID_call, 4, rb_float_new(t),
 					 vy, vmjac, vdfdt);
-  else result = rb_funcall((VALUE) proc, ID_call, 5, rb_float_new(t), 
+  else result = rb_funcall((VALUE) proc, RBGSL_ID_call, 5, rb_float_new(t), 
 			   vy, vmjac, vdfdt, params);
   return GSL_SUCCESS;
 }
@@ -237,15 +237,7 @@ static VALUE rb_gsl_odeiv_system_set_params(int argc, VALUE *argv, VALUE obj)
   gsl_odeiv_system *sys = NULL;
   size_t i;
   Data_Get_Struct(obj, gsl_odeiv_system, sys);
-  /*  ary = rb_ary_new2(4);
-  for (i= 0; i < 4; i++) {
-    printf("yoshiki %d\n", (int) i);
-    rb_gc_mark(rb_ary_entry((VALUE) sys->params, i));
-    printf("yoshiki %d\n", (int) i+100);
-    rb_ary_store(ary, i, rb_ary_entry((VALUE) sys->params, i));
-    printf("yoshiki %d\n", (int) i+200);
-  }
-  sys->params = (void*) ary;*/
+
   ary = (VALUE) sys->params;
   switch (argc) {
   case 0:
