@@ -553,13 +553,20 @@ void Init_gsl_permutation(VALUE module)
   rb_define_method(cgsl_permutation, "prev", rb_gsl_permutation_prev, 0);
 
   rb_define_method(cgsl_permutation, "permute_vector", rb_gsl_permutation_permute_vector, 1);
+  rb_define_alias(cgsl_permutation, "permute", "permute_vector");
   rb_define_method(cgsl_permutation, "permute_vector_inverse", rb_gsl_permutation_permute_vector_inverse, 1);
-
+  rb_define_alias(cgsl_permutation, "permute_inverse", "permute_vector_inverse");
+  
   rb_define_singleton_method(cgsl_permutation, "permute_vector", rb_gsl_permute_vector, 2);
   rb_define_singleton_method(cgsl_permutation, "permute_vector_inverse", rb_gsl_permute_vector_inverse, 2);
   rb_define_module_function(module, "permute_vector", rb_gsl_permute_vector, 2);
   rb_define_module_function(module, "permute_vector_inverse", rb_gsl_permute_vector_inverse, 2);
 
+  rb_define_singleton_method(cgsl_permutation, "permute", rb_gsl_permute_vector, 2);
+  rb_define_singleton_method(cgsl_permutation, "permute_inverse", rb_gsl_permute_vector_inverse, 2);
+  rb_define_module_function(module, "permute", rb_gsl_permute_vector, 2);
+  rb_define_module_function(module, "permute_inverse", rb_gsl_permute_vector_inverse, 2);
+
   rb_define_method(cgsl_permutation, "fwrite", rb_gsl_permutation_fwrite, 1);
   rb_define_method(cgsl_permutation, "fread", rb_gsl_permutation_fread, 1);
   rb_define_method(cgsl_permutation, "fprintf", rb_gsl_permutation_fprintf, -1);
