@@ -65,6 +65,94 @@ double gsl_poly_int_eval(const BASE c[], const int len, const double x)
   for(i=len-1; i>0; i--) ans = (double) c[i-1] + x * ans;
   return ans;
 }
+#endif
+#ifdef BASE_DOUBLE
+#ifdef HAVE_NARRAY_H
+#include "rb_gsl_with_narray.h"
+#endif
+static VALUE rb_gsl_poly_eval_singleton(VALUE klass, VALUE a, VALUE x)
+{
+  gsl_vector *v = NULL, *vx, *vnew;
+  gsl_matrix *mx, *mnew;
+  double rslt;
+  int flag = 0;
+  size_t i, N, n;
+  VALUE val;
+  double *ptr0;
+  double *ptr1, *ptr2;  
+#ifdef HAVE_NARRAY_H
+  int shape[1];
+#endif  
+  switch (TYPE(a)) {
+  case T_ARRAY:
+    v = make_cvector_from_rarray(a);
+    N = v->size;
+    ptr0 = v->data;
+    flag = 1;
+    break;
+  default:
+    if (rb_obj_is_kind_of(a, cgsl_vector)) {
+      Data_Get_Struct(a, gsl_vector, v);
+      N = v->size;
+      ptr0 = v->data;
+#ifdef HAVE_NARRAY_H
+    } else if (NA_IsNArray(a)) {
+      N = NA_TOTAL(a);
+      ptr0 = NA_PTR_TYPE(a, double*);
+#endif
+    } else {
+      rb_raise(rb_eTypeError, "Wrong argument type %s (Array, GSL::Vector or NArray expected)",
+        rb_class2name(CLASS_OF(a)));
+    }
+  }
+  switch (TYPE(x)) {
+  case T_FIXNUM:
+  case T_BIGNUM:
+  case T_FLOAT:
+    val = rb_float_new(gsl_poly_eval(ptr0, N, NUM2DBL(x)));
+    break;    
+  case T_ARRAY:
+    n = RARRAY(x)->len;
+    val = rb_ary_new2(n);
+    for (i = 0; i < n; i++) {
+      rslt = gsl_poly_eval(ptr0, N, NUM2DBL(rb_ary_entry(x, i)));
+      rb_ary_store(val, i, rb_float_new(rslt));
+    }
+    break;  
+  default:
+    if (rb_obj_is_kind_of(x, cgsl_vector)) {
+      Data_Get_Struct(x, gsl_vector, vx);
+      vnew = gsl_vector_alloc(vx->size);
+      val = Data_Wrap_Struct(cgsl_vector, 0, gsl_vector_free, vnew);
+      n = vx->size;
+      ptr1 = vx->data;
+      ptr2 = vnew->data;
+    } else if (rb_obj_is_kind_of(x, cgsl_matrix)) {
+      Data_Get_Struct(x, gsl_matrix, mx);
+      mnew = gsl_matrix_alloc(mx->size1, mx->size2);
+      val = Data_Wrap_Struct(cgsl_matrix, 0, gsl_matrix_free, mnew);      
+      n = mx->size1*mx->size2;
+      ptr1 = mx->data;
+      ptr2 = mnew->data;
+#ifdef HAVE_NARRAY_H
+    } else if (NA_IsNArray(x)) {
+      shape[0] = NA_TOTAL(x);
+      n = shape[0];
+      val = na_make_object(NA_DFLOAT, 1, shape, CLASS_OF(x));
+      ptr1 = NA_PTR_TYPE(x, double*);
+      ptr2 = NA_PTR_TYPE(val, double*);      
+#endif
+    } else {
+      rb_raise(rb_eTypeError, "Wrong argument type %s (A number, Array, GSL::Vector or NArray expected)",
+        rb_class2name(CLASS_OF(a)));      
+    }
+    for (i = 0; i < n; i++) {
+      ptr2[i] = gsl_poly_eval(ptr0, N, ptr1[i]);
+    }
+  }
+  if (flag == 1) gsl_vector_free(v);
+  return val;
+}
 
 #endif
 
@@ -1504,6 +1592,7 @@ void FUNCTION(Init_gsl_poly,init)(VALUE module)
 #endif
 
 #ifdef BASE_DOUBLE
+  rb_define_singleton_method(cgsl_poly, "eval", rb_gsl_poly_eval_singleton, 2);
   rb_define_method(cgsl_poly, "to_i", rb_gsl_poly_to_i, 0);
 #ifdef GSL_1_1_LATER
   cgsl_poly_dd = rb_define_class_under(cgsl_poly, "DividedDifference", cgsl_poly);
