@@ -21,7 +21,7 @@ VALUE cgsl_sf_result, cgsl_sf_result_e10;
 VALUE rb_gsl_sf_result_new(VALUE klass)
 {
   gsl_sf_result *rslt = NULL;
-  return Data_Make_Struct(cgsl_sf_result, gsl_sf_result, 0, free, rslt);
+  return Data_Make_Struct(klass, gsl_sf_result, 0, free, rslt);
 }
 
 static VALUE rb_gsl_sf_result_print(VALUE obj)
@@ -336,10 +336,10 @@ VALUE rb_gsl_sf_eval_int_int_double(double (*func)(int, int, double), VALUE jj,
       Data_Get_Struct(argv, gsl_matrix, m);
       mnew = gsl_matrix_alloc(m->size1, m->size2);
       for (i = 0; i < m->size1; i++) {
-	for (k = 0; k < m->size2; k++) {
-	  val = (*func)(j, j2, gsl_matrix_get(m, i, k));
-	  gsl_matrix_set(mnew, i, k, val);
-	}
+        for (k = 0; k < m->size2; k++) {
+          val = (*func)(j, j2, gsl_matrix_get(m, i, k));
+          gsl_matrix_set(mnew, i, k, val);
+        }
       }
       return Data_Wrap_Struct(cgsl_matrix, 0, gsl_matrix_free, mnew);
     } else {
@@ -348,8 +348,8 @@ VALUE rb_gsl_sf_eval_int_int_double(double (*func)(int, int, double), VALUE jj,
       n = v->size;
       vnew = gsl_vector_alloc(n);
       for (i = 0; i < n; i++) {
-	val = (*func)(j, j2, gsl_vector_get(v, i));
-	gsl_vector_set(vnew, i, val);
+        val = (*func)(j, j2, gsl_vector_get(v, i));
+        gsl_vector_set(vnew, i, val);
       }
       return Data_Wrap_Struct(cgsl_vector, 0, gsl_vector_free, vnew);
     }
