@@ -442,7 +442,7 @@ static VALUE rb_gsl_stats_covariance_m2(VALUE obj, VALUE vv1, VALUE vv2,
 					   stride2, size, NUM2DBL(m1), NUM2DBL(m2)));
 }
 
-#ifdef HAVE_GSL_STATS_CORRELATION
+#ifdef GSL_1_10_LATER
 static VALUE rb_gsl_stats_correlation(VALUE obj, VALUE vv1, VALUE vv2)
 {
   double *data1, *data2;
@@ -452,6 +452,24 @@ static VALUE rb_gsl_stats_correlation(VALUE obj, VALUE vv1, VALUE vv2)
   return rb_float_new(gsl_stats_correlation(data1, stride1, data2,
 					   stride2, size));
 }
+static VALUE rb_gsl_stats_pvariance(VALUE obj, VALUE vv1, VALUE vv2)
+{
+  double *data1, *data2;
+  size_t stride1, stride2, size1, size2;
+  data1 = get_vector_ptr(vv1, &stride1, &size1);
+  data2 = get_vector_ptr(vv2, &stride2, &size2);
+  return rb_float_new(gsl_stats_pvariance(data1, stride1, size1, data2,
+					   stride2, size2));
+}
+static VALUE rb_gsl_stats_ttest(VALUE obj, VALUE vv1, VALUE vv2)
+{
+  double *data1, *data2;
+  size_t stride1, stride2, size1, size2;
+  data1 = get_vector_ptr(vv1, &stride1, &size1);
+  data2 = get_vector_ptr(vv2, &stride2, &size2);
+  return rb_float_new(gsl_stats_ttest(data1, stride1, size1, data2,
+					   stride2, size2));
+}
 #endif
 
 static VALUE rb_gsl_stats_wmean2(VALUE obj, VALUE ww, VALUE dd)
@@ -674,8 +692,10 @@ void Init_gsl_stats(VALUE module)
   rb_define_singleton_method(mgsl_stats, "covariance", rb_gsl_stats_covariance2, 2);
   rb_define_singleton_method(mgsl_stats, "covariance_m", rb_gsl_stats_covariance_m2, 4);
   
-#ifdef HAVE_GSL_STATS_CORRELATION
+#ifdef GSL_1_10_LATER
   rb_define_singleton_method(mgsl_stats, "correlation", rb_gsl_stats_correlation, 2);  
+  rb_define_singleton_method(mgsl_stats, "pvariance", rb_gsl_stats_pvariance, 2);    
+  rb_define_singleton_method(mgsl_stats, "ttest", rb_gsl_stats_ttest, 2);      
 #endif
 
   /*****/
