@@ -17,6 +17,7 @@ static VALUE rb_gsl_vector_complex_inner_product(int argc, VALUE *argv, VALUE ob
 static VALUE rb_gsl_vector_complex_product_to_m(int argc, VALUE *argv, VALUE obj);
 void get_range_beg_en_n(VALUE range, int *beg, int *en, size_t *n, int *step);
 
+
 static VALUE rb_gsl_vector_complex_new(int argc, VALUE *argv, VALUE klass)
 {
   VALUE tmp;
@@ -1565,6 +1566,52 @@ static VALUE rb_gsl_vector_complex_zip(int argc, VALUE *argv, VALUE obj)
   return ary;
 }
 
+static int gsl_vector_complex_equal(const gsl_vector_complex *v1,
+  const gsl_vector_complex *v2, double eps)
+{
+  gsl_complex z1, z2;
+  size_t i;
+  if (v1->size != v2->size) return 0;
+  for (i = 0; i < v1->size; i++) {
+    z1 = gsl_vector_complex_get(v1, i);
+    z2 = gsl_vector_complex_get(v2, i);
+    if (!rbgsl_complex_equal(&z1, &z2, eps)) return 0;
+  }
+  return 1;
+  
+}
+
+static VALUE rb_gsl_vector_complex_equal(int argc, VALUE *argv, VALUE obj)
+{
+  gsl_vector_complex *v1, *v2;
+  double eps = 1e-8;
+  int ret;
+  switch (argc) {
+  case 1:
+    eps = 1e-8;
+    break;
+  case 2:
+    eps = NUM2DBL(argv[1]);
+    break;
+  default:
+    rb_raise(rb_eArgError, "Wrong number of arguments (%d for 1 or 2)\n", argc);
+  }
+  Data_Get_Struct(obj, gsl_vector_complex, v1);
+  CHECK_VECTOR_COMPLEX(argv[0]);
+  Data_Get_Struct(argv[0], gsl_vector_complex, v2);
+  ret = gsl_vector_complex_equal(v1, v2, eps);
+  if (ret == 1) return Qtrue;
+  else return Qfalse;
+}
+
+static VALUE rb_gsl_vector_complex_not_equal(int argc, VALUE *argv, VALUE obj)
+{
+  VALUE ret;
+  ret = rb_gsl_vector_complex_equal(argc, argv, obj);
+  if (ret == Qtrue) return Qfalse;
+  else return Qtrue;
+}
+
 void Init_gsl_vector_complex(VALUE module)
 {
   rb_define_singleton_method(cgsl_vector_complex, "new", rb_gsl_vector_complex_new, -1);
@@ -1727,5 +1774,10 @@ void Init_gsl_vector_complex(VALUE module)
 
   rb_define_method(cgsl_vector_complex, "zip", rb_gsl_vector_complex_zip, -1);
   rb_define_singleton_method(cgsl_vector_complex, "zip", rb_gsl_vector_complex_zip, -1);
+  
+  rb_define_method(cgsl_vector_complex, "equal?", rb_gsl_vector_complex_equal, -1);
+  rb_define_alias(cgsl_vector_complex, "==", "equal?");
+  rb_define_method(cgsl_vector_complex, "not_equal?", rb_gsl_vector_complex_not_equal, -1);
+  rb_define_alias(cgsl_vector_complex, "!=", "not_equal?");  
 }
 
