@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 # Ruby/GSL implementation of GSL "qrng/test.c"
-require("rbgsl")
+require("gsl")
 require("./gsl_test2.rb")
 include GSL::Test
 include Math
